@@ -177,12 +177,12 @@ class SmartIrManager:  # pylint: disable=too-many-instance-attributes
 
         except KeyError as key_err:
             raise click.exceptions.UsageError(f"Missing mandatory field in json file: {key_err}") from None
-        else:
-            self._setup_combinations()
-            self.__temperature = ''
-            self.__operation_mode = ''
-            self.__fan_mode = ''
-            self.__swing_mode = ''
+
+        self._setup_combinations()
+        self.__temperature = ''
+        self.__operation_mode = ''
+        self.__fan_mode = ''
+        self.__swing_mode = ''
         self._setup_signal_handler()
 
     @property
@@ -203,8 +203,6 @@ class SmartIrManager:  # pylint: disable=too-many-instance-attributes
             signal.signal(signal.SIGTERM, self._signal_handler)
         if _system == 'windows':
             signal.signal(signal.SIGBREAK, self._signal_handler)  # pylint: disable=no-member
-            signal.signal(signal.CTRL_C_EVENT, self._signal_handler)  # pylint: disable=no-member
-            signal.signal(signal.CTRL_BREAK_EVENT, self._signal_handler)  # pylint: disable=no-member
 
     def _signal_handler(self, _signumber, _frame):
         self._save_partial_dict()
@@ -411,10 +409,10 @@ class SmartIrManager:  # pylint: disable=too-many-instance-attributes
             del _no_off['commands']['off']
         except KeyError:
             return
-        else:
-            with open(_modified_file_name, 'w', encoding='utf-8') as out_file:
-                json.dump(_no_off[_DictKeys.COMMANDS.value], out_file, indent=2)
-            self.__partial_inc += 1
+
+        with open(_modified_file_name, 'w', encoding='utf-8') as out_file:
+            json.dump(_no_off[_DictKeys.COMMANDS.value], out_file, indent=2)
+        self.__partial_inc += 1
 
     def _load_partial_dict(self):
         _previous = glob.glob(
